pub struct CommandIntStamped {}Expand description
MAVLink COMMAND_INT_STAMPED message.
The minimum supported MAVLink version is MAVLink 1.
Description
Message encoding a command with parameters as scaled integers and additional metadata. Scaling depends on the actual command value.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
CommandIntStamped (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
utc_time: u32MAVLink field utc_time.
UTC time, seconds elapsed since 01.01.1970
vehicle_timestamp: u64MAVLink field vehicle_timestamp.
Microseconds elapsed since vehicle boot
target_system: u8MAVLink field target_system.
System ID
target_component: u8MAVLink field target_component.
Component ID
frame: MavFrameMAVLink field frame.
The coordinate system of the COMMAND, as defined by MAV_FRAME enum
command: MavCmdMAVLink field command.
The scheduled action for the mission item, as defined by MAV_CMD enum
current: u8MAVLink field current.
false:0, true:1
autocontinue: u8MAVLink field autocontinue.
autocontinue to next wp
param1: f32MAVLink field param1.
PARAM1, see MAV_CMD enum
param2: f32MAVLink field param2.
PARAM2, see MAV_CMD enum
param3: f32MAVLink field param3.
PARAM3, see MAV_CMD enum
param4: f32MAVLink field param4.
PARAM4, see MAV_CMD enum
x: i32MAVLink field x.
PARAM5 / local: x position in meters * 1e4, global: latitude in degrees * 10^7
y: i32MAVLink field y.
PARAM6 / local: y position in meters * 1e4, global: longitude in degrees * 10^7
z: f32MAVLink field z.
PARAM7 / z position: global: altitude in meters (MSL, WGS84, AGL or relative to home - depending on frame).
Implementations
Sourceimpl CommandIntStamped
impl CommandIntStamped
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.