AutopilotVersion

Type Alias AutopilotVersion 

pub type AutopilotVersion = AutopilotVersion;
Originally defined in common::messages::autopilot_version.

Aliased Type

pub struct AutopilotVersion {
    pub capabilities: MavProtocolCapability,
    pub flight_sw_version: u32,
    pub middleware_sw_version: u32,
    pub os_sw_version: u32,
    pub board_version: u32,
    pub flight_custom_version: [u8; 8],
    pub middleware_custom_version: [u8; 8],
    pub os_custom_version: [u8; 8],
    pub vendor_id: u16,
    pub product_id: u16,
    pub uid: u64,
    pub uid2: [u8; 18],
}

Fields

capabilities: MavProtocolCapability

MAVLink field capabilities.

Bitmap of capabilities

flight_sw_version: u32

MAVLink field flight_sw_version.

Firmware version number. The field must be encoded as 4 bytes, where each byte (shown from MSB to LSB) is part of a semantic version: (major) (minor) (patch) (FIRMWARE_VERSION_TYPE).

middleware_sw_version: u32

MAVLink field middleware_sw_version.

Middleware version number

os_sw_version: u32

MAVLink field os_sw_version.

Operating system version number

board_version: u32

MAVLink field board_version.

HW / board version (last 8 bits should be silicon ID, if any). The first 16 bits of this field specify https://github.com/PX4/PX4-Bootloader/blob/master/board_types.txt

flight_custom_version: [u8; 8]

MAVLink field flight_custom_version.

Custom version field, commonly the first 8 bytes of the git hash. This is not an unique identifier, but should allow to identify the commit using the main version number even for very large code bases.

middleware_custom_version: [u8; 8]

MAVLink field middleware_custom_version.

Custom version field, commonly the first 8 bytes of the git hash. This is not an unique identifier, but should allow to identify the commit using the main version number even for very large code bases.

os_custom_version: [u8; 8]

MAVLink field os_custom_version.

Custom version field, commonly the first 8 bytes of the git hash. This is not an unique identifier, but should allow to identify the commit using the main version number even for very large code bases.

vendor_id: u16

MAVLink field vendor_id.

ID of the board vendor

product_id: u16

MAVLink field product_id.

ID of the product

uid: u64

MAVLink field uid.

UID if provided by hardware (see uid2)

uid2: [u8; 18]

MAVLink field uid2.

UID if provided by hardware (supersedes the uid field. If this is non-zero, use this field, otherwise use uid)