Type Alias CellularConfig

pub type CellularConfig = CellularConfig;
Originally defined in common::messages::cellular_config.

Aliased Type

struct CellularConfig {
    pub enable_lte: u8,
    pub enable_pin: u8,
    pub pin: [u8; 16],
    pub new_pin: [u8; 16],
    pub apn: [u8; 32],
    pub puk: [u8; 16],
    pub roaming: u8,
    pub response: CellularConfigResponse,
}

Fields

enable_lte: u8

MAVLink field enable_lte.

Enable/disable LTE. 0: setting unchanged, 1: disabled, 2: enabled. Current setting when sent back as a response.

enable_pin: u8

MAVLink field enable_pin.

Enable/disable PIN on the SIM card. 0: setting unchanged, 1: disabled, 2: enabled. Current setting when sent back as a response.

pin: [u8; 16]

MAVLink field pin.

PIN sent to the SIM card. Blank when PIN is disabled. Empty when message is sent back as a response.

new_pin: [u8; 16]

MAVLink field new_pin.

New PIN when changing the PIN. Blank to leave it unchanged. Empty when message is sent back as a response.

apn: [u8; 32]

MAVLink field apn.

Name of the cellular APN. Blank to leave it unchanged. Current APN when sent back as a response.

puk: [u8; 16]

MAVLink field puk.

Required PUK code in case the user failed to authenticate 3 times with the PIN. Empty when message is sent back as a response.

roaming: u8

MAVLink field roaming.

Enable/disable roaming. 0: setting unchanged, 1: disabled, 2: enabled. Current setting when sent back as a response.

response: CellularConfigResponse

MAVLink field response.

Message acceptance response (sent back to GS).