ComponentMetadata

Type Alias ComponentMetadata 

pub type ComponentMetadata = ComponentMetadata;
Originally defined in common::messages::component_metadata.

Aliased Type

pub struct ComponentMetadata {
    pub time_boot_ms: u32,
    pub file_crc: u32,
    pub uri: [u8; 100],
}

Fields

time_boot_ms: u32

MAVLink field time_boot_ms.

Timestamp (time since system boot).

file_crc: u32

MAVLink field file_crc.

CRC32 of the general metadata file.

uri: [u8; 100]

MAVLink field uri.

MAVLink FTP URI for the general metadata file (COMP_METADATA_TYPE_GENERAL), which may be compressed with xz. The file contains general component metadata, and may contain URI links for additional metadata (see COMP_METADATA_TYPE). The information is static from boot, and may be generated at compile time. The string needs to be zero terminated.