CurrentMode

Type Alias CurrentMode 

pub type CurrentMode = CurrentMode;
Originally defined in common::messages::current_mode.

Aliased Type

pub struct CurrentMode {
    pub standard_mode: MavStandardMode,
    pub custom_mode: u32,
    pub intended_custom_mode: u32,
}

Fields

standard_mode: MavStandardMode

MAVLink field standard_mode.

Standard mode.

custom_mode: u32

MAVLink field custom_mode.

A bitfield for use for autopilot-specific flags

intended_custom_mode: u32

MAVLink field intended_custom_mode.

The custom_mode of the mode that was last commanded by the user (for example, with MAV_CMD_DO_SET_STANDARD_MODE, MAV_CMD_DO_SET_MODE or via RC). This should usually be the same as custom_mode. It will be different if the vehicle is unable to enter the intended mode, or has left that mode due to a failsafe condition. 0 indicates the intended custom mode is unknown/not supplied