FigureEightExecutionStatus

Type Alias FigureEightExecutionStatus 

pub type FigureEightExecutionStatus = FigureEightExecutionStatus;
Aliased Type

pub struct FigureEightExecutionStatus {
    pub time_usec: u64,
    pub major_radius: f32,
    pub minor_radius: f32,
    pub orientation: f32,
    pub frame: MavFrame,
    pub x: i32,
    pub y: i32,
    pub z: f32,
}

Fields

time_usec: u64

MAVLink field time_usec.

Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.

major_radius: f32

MAVLink field major_radius.

Major axis radius of the figure eight. Positive: orbit the north circle clockwise. Negative: orbit the north circle counter-clockwise.

minor_radius: f32

MAVLink field minor_radius.

Minor axis radius of the figure eight. Defines the radius of two circles that make up the figure.

orientation: f32

MAVLink field orientation.

Orientation of the figure eight major axis with respect to true north in [-pi,pi).

frame: MavFrame

MAVLink field frame.

The coordinate system of the fields: x, y, z.

x: i32

MAVLink field x.

X coordinate of center point. Coordinate system depends on frame field.

y: i32

MAVLink field y.

Y coordinate of center point. Coordinate system depends on frame field.

z: f32

MAVLink field z.

Altitude of center point. Coordinate system depends on frame field.