ParamMapRc

Type Alias ParamMapRc 

pub type ParamMapRc = ParamMapRc;
Originally defined in common::messages::param_map_rc.

Aliased Type

pub struct ParamMapRc {
    pub target_system: u8,
    pub target_component: u8,
    pub param_id: [u8; 16],
    pub param_index: i16,
    pub parameter_rc_channel_index: u8,
    pub param_value0: f32,
    pub scale: f32,
    pub param_value_min: f32,
    pub param_value_max: f32,
}

Fields

target_system: u8

MAVLink field target_system.

System ID

target_component: u8

MAVLink field target_component.

Component ID

param_id: [u8; 16]

MAVLink field param_id.

Onboard parameter id, terminated by NULL if the length is less than 16 human-readable chars and WITHOUT null termination (NULL) byte if the length is exactly 16 chars

  • applications have to provide 16+1 bytes storage if the ID is stored as string
param_index: i16

MAVLink field param_index.

Parameter index. Send -1 to use the param ID field as identifier (else the param id will be ignored), send -2 to disable any existing map for this rc_channel_index.

parameter_rc_channel_index: u8

MAVLink field parameter_rc_channel_index.

Index of parameter RC channel. Not equal to the RC channel id. Typically corresponds to a potentiometer-knob on the RC.

param_value0: f32

MAVLink field param_value0.

Initial parameter value

scale: f32

MAVLink field scale.

Scale, maps the RC range [-1, 1] to a parameter value

param_value_min: f32

MAVLink field param_value_min.

Minimum param value. The protocol does not define if this overwrites an onboard minimum value. (Depends on implementation)

param_value_max: f32

MAVLink field param_value_max.

Maximum param value. The protocol does not define if this overwrites an onboard maximum value. (Depends on implementation)