ParamValueArray

Type Alias ParamValueArray 

pub type ParamValueArray = ParamValueArray;
Originally defined in storm32::messages::param_value_array.

Aliased Type

pub struct ParamValueArray {
    pub param_count: u16,
    pub param_index_first: u16,
    pub param_array_len: u8,
    pub flags: u16,
    pub packet_buf: [u8; 248],
}

Fields

param_count: u16

MAVLink field param_count.

Total number of onboard parameters.

param_index_first: u16

MAVLink field param_index_first.

Index of the first onboard parameter in this array.

param_array_len: u8

MAVLink field param_array_len.

Number of onboard parameters in this array.

flags: u16

MAVLink field flags.

Flags.

packet_buf: [u8; 248]

MAVLink field packet_buf.

Parameters buffer. Contains a series of variable length parameter blocks, one per parameter, with format as specified elsewhere.