Type Alias SetHomePosition

pub type SetHomePosition = SetHomePosition;
Originally defined in common::messages::set_home_position.

Aliased Type

pub struct SetHomePosition {
    pub target_system: u8,
    pub latitude: i32,
    pub longitude: i32,
    pub altitude: i32,
    pub x: f32,
    pub y: f32,
    pub z: f32,
    pub q: [f32; 4],
    pub approach_x: f32,
    pub approach_y: f32,
    pub approach_z: f32,
    pub time_usec: u64,
}

Fields

target_system: u8

MAVLink field target_system.

System ID.

latitude: i32

MAVLink field latitude.

Latitude (WGS84)

longitude: i32

MAVLink field longitude.

Longitude (WGS84)

altitude: i32

MAVLink field altitude.

Altitude (MSL). Positive for up.

x: f32

MAVLink field x.

Local X position of this position in the local coordinate frame (NED)

y: f32

MAVLink field y.

Local Y position of this position in the local coordinate frame (NED)

z: f32

MAVLink field z.

Local Z position of this position in the local coordinate frame (NED: positive “down”)

q: [f32; 4]

MAVLink field q.

World to surface normal and heading transformation of the takeoff position. Used to indicate the heading and slope of the ground

approach_x: f32

MAVLink field approach_x.

Local X position of the end of the approach vector. Multicopters should set this position based on their takeoff path. Grass-landing fixed wing aircraft should set it the same way as multicopters. Runway-landing fixed wing aircraft should set it to the opposite direction of the takeoff, assuming the takeoff happened from the threshold / touchdown zone.

approach_y: f32

MAVLink field approach_y.

Local Y position of the end of the approach vector. Multicopters should set this position based on their takeoff path. Grass-landing fixed wing aircraft should set it the same way as multicopters. Runway-landing fixed wing aircraft should set it to the opposite direction of the takeoff, assuming the takeoff happened from the threshold / touchdown zone.

approach_z: f32

MAVLink field approach_z.

Local Z position of the end of the approach vector. Multicopters should set this position based on their takeoff path. Grass-landing fixed wing aircraft should set it the same way as multicopters. Runway-landing fixed wing aircraft should set it to the opposite direction of the takeoff, assuming the takeoff happened from the threshold / touchdown zone.

time_usec: u64

MAVLink field time_usec.

Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.