Type Alias SysStatus

pub type SysStatus = SysStatus;
Originally defined in common::messages::sys_status.

Aliased Type

struct SysStatus {
Show 16 fields pub onboard_control_sensors_present: MavSysStatusSensor, pub onboard_control_sensors_enabled: MavSysStatusSensor, pub onboard_control_sensors_health: MavSysStatusSensor, pub load: u16, pub voltage_battery: u16, pub current_battery: i16, pub battery_remaining: i8, pub drop_rate_comm: u16, pub errors_comm: u16, pub errors_count1: u16, pub errors_count2: u16, pub errors_count3: u16, pub errors_count4: u16, pub onboard_control_sensors_present_extended: MavSysStatusSensorExtended, pub onboard_control_sensors_enabled_extended: MavSysStatusSensorExtended, pub onboard_control_sensors_health_extended: MavSysStatusSensorExtended,
}

Fields

onboard_control_sensors_present: MavSysStatusSensor

MAVLink field onboard_control_sensors_present.

Bitmap showing which onboard controllers and sensors are present. Value of 0: not present. Value of 1: present.

onboard_control_sensors_enabled: MavSysStatusSensor

MAVLink field onboard_control_sensors_enabled.

Bitmap showing which onboard controllers and sensors are enabled: Value of 0: not enabled. Value of 1: enabled.

onboard_control_sensors_health: MavSysStatusSensor

MAVLink field onboard_control_sensors_health.

Bitmap showing which onboard controllers and sensors have an error (or are operational). Value of 0: error. Value of 1: healthy.

load: u16

MAVLink field load.

Maximum usage in percent of the mainloop time. Values: [0-1000] - should always be below 1000

voltage_battery: u16

MAVLink field voltage_battery.

Battery voltage, UINT16_MAX: Voltage not sent by autopilot

current_battery: i16

MAVLink field current_battery.

Battery current, -1: Current not sent by autopilot

battery_remaining: i8

MAVLink field battery_remaining.

Battery energy remaining, -1: Battery remaining energy not sent by autopilot

drop_rate_comm: u16

MAVLink field drop_rate_comm.

Communication drop rate, (UART, I2C, SPI, CAN), dropped packets on all links (packets that were corrupted on reception on the MAV)

errors_comm: u16

MAVLink field errors_comm.

Communication errors (UART, I2C, SPI, CAN), dropped packets on all links (packets that were corrupted on reception on the MAV)

errors_count1: u16

MAVLink field errors_count1.

Autopilot-specific errors

errors_count2: u16

MAVLink field errors_count2.

Autopilot-specific errors

errors_count3: u16

MAVLink field errors_count3.

Autopilot-specific errors

errors_count4: u16

MAVLink field errors_count4.

Autopilot-specific errors

onboard_control_sensors_present_extended: MavSysStatusSensorExtended

MAVLink field onboard_control_sensors_present_extended.

Bitmap showing which onboard controllers and sensors are present. Value of 0: not present. Value of 1: present.

onboard_control_sensors_enabled_extended: MavSysStatusSensorExtended

MAVLink field onboard_control_sensors_enabled_extended.

Bitmap showing which onboard controllers and sensors are enabled: Value of 0: not enabled. Value of 1: enabled.

onboard_control_sensors_health_extended: MavSysStatusSensorExtended

MAVLink field onboard_control_sensors_health_extended.

Bitmap showing which onboard controllers and sensors have an error (or are operational). Value of 0: error. Value of 1: healthy.