MotorTestOrder

Enum MotorTestOrder 

#[repr(u8)]
pub enum MotorTestOrder { Default = 0, Sequence = 1, Board = 2, }
MAVLink enum MOTOR_TEST_ORDER for common dialect.

Sequence that motors are tested when using MAV_CMD_DO_MOTOR_TEST.

Variants



Default = 0

MAVLink enum entry MOTOR_TEST_ORDER_DEFAULT.

Default autopilot motor test method.



Sequence = 1

MAVLink enum entry MOTOR_TEST_ORDER_SEQUENCE.

Motor numbers are specified as their index in a predefined vehicle-specific sequence.



Board = 2

MAVLink enum entry MOTOR_TEST_ORDER_BOARD.

Motor numbers are specified as the output as labeled on the board.

Implementations

Source

impl MotorTestOrder

pub fn name() -> &'static str

Returns a canonical MAVLink name

pub fn entries() -> impl Iterator<Item = Self>

Iterator over all entries within this enum.

Requires metadata feature flag to be enabled.

pub fn value(&self) -> u8

Returns value of this enum variant.

Requires metadata feature flag to be enabled.