SetFocusType

Enum SetFocusType 

#[repr(u8)]
pub enum SetFocusType { FocusTypeStep = 0, FocusTypeContinuous = 1, FocusTypeRange = 2, FocusTypeMeters = 3, FocusTypeAuto = 4, FocusTypeAutoSingle = 5, FocusTypeAutoContinuous = 6, }
MAVLink enum SET_FOCUS_TYPE for common dialect.

Focus types for MAV_CMD_SET_CAMERA_FOCUS

Variants



FocusTypeStep = 0

MAVLink enum entry FOCUS_TYPE_STEP.

Focus one step increment (-1 for focusing in, 1 for focusing out towards infinity).



FocusTypeContinuous = 1

MAVLink enum entry FOCUS_TYPE_CONTINUOUS.

Continuous normalized focus in/out rate until stopped. Range -1..1, negative: in, positive: out towards infinity, 0 to stop focusing. Other values should be clipped to the range.



FocusTypeRange = 2

MAVLink enum entry FOCUS_TYPE_RANGE.

Focus value as proportion of full camera focus range (a value between 0.0 and 100.0)



FocusTypeMeters = 3

MAVLink enum entry FOCUS_TYPE_METERS.

Focus value in metres. Note that there is no message to get the valid focus range of the camera, so this can type can only be used for cameras where the range is known (implying that this cannot reliably be used in a GCS for an arbitrary camera).



FocusTypeAuto = 4

MAVLink enum entry FOCUS_TYPE_AUTO.

Focus automatically.



FocusTypeAutoSingle = 5

MAVLink enum entry FOCUS_TYPE_AUTO_SINGLE.

Single auto focus. Mainly used for still pictures. Usually abbreviated as AF-S.



FocusTypeAutoContinuous = 6

MAVLink enum entry FOCUS_TYPE_AUTO_CONTINUOUS.

Continuous auto focus. Mainly used for dynamic scenes. Abbreviated as AF-C.

Implementations

Source

impl SetFocusType

pub fn name() -> &'static str

Returns a canonical MAVLink name

pub fn entries() -> impl Iterator<Item = Self>

Iterator over all entries within this enum.

Requires metadata feature flag to be enabled.

pub fn value(&self) -> u8

Returns value of this enum variant.

Requires metadata feature flag to be enabled.