CameraCapFlags

Struct CameraCapFlags 

pub struct CameraCapFlags(/* private fields */);
MAVLink bitmask enum CAMERA_CAP_FLAGS for common dialect.

Camera capability flags (Bitmap)

Implementations

Source

impl CameraCapFlags

pub const CAPTURE_VIDEO: Self

CAMERA_CAP_FLAGS_CAPTURE_VIDEO flag.

Camera is able to record video

pub const CAPTURE_IMAGE: Self

CAMERA_CAP_FLAGS_CAPTURE_IMAGE flag.

Camera is able to capture images

pub const HAS_MODES: Self

CAMERA_CAP_FLAGS_HAS_MODES flag.

Camera has separate Video and Image/Photo modes (MAV_CMD_SET_CAMERA_MODE)

pub const CAN_CAPTURE_IMAGE_IN_VIDEO_MODE: Self

CAMERA_CAP_FLAGS_CAN_CAPTURE_IMAGE_IN_VIDEO_MODE flag.

Camera can capture images while in video mode

pub const CAN_CAPTURE_VIDEO_IN_IMAGE_MODE: Self

CAMERA_CAP_FLAGS_CAN_CAPTURE_VIDEO_IN_IMAGE_MODE flag.

Camera can capture videos while in Photo/Image mode

pub const HAS_IMAGE_SURVEY_MODE: Self

CAMERA_CAP_FLAGS_HAS_IMAGE_SURVEY_MODE flag.

Camera has image survey mode (MAV_CMD_SET_CAMERA_MODE)

pub const HAS_BASIC_ZOOM: Self

CAMERA_CAP_FLAGS_HAS_BASIC_ZOOM flag.

Camera has basic zoom control (MAV_CMD_SET_CAMERA_ZOOM)

pub const HAS_BASIC_FOCUS: Self

CAMERA_CAP_FLAGS_HAS_BASIC_FOCUS flag.

Camera has basic focus control (MAV_CMD_SET_CAMERA_FOCUS)

pub const HAS_VIDEO_STREAM: Self

CAMERA_CAP_FLAGS_HAS_VIDEO_STREAM flag.

Camera has video streaming capabilities (request VIDEO_STREAM_INFORMATION with MAV_CMD_REQUEST_MESSAGE for video streaming info)

pub const HAS_TRACKING_POINT: Self

CAMERA_CAP_FLAGS_HAS_TRACKING_POINT flag.

Camera supports tracking of a point on the camera view.

pub const HAS_TRACKING_RECTANGLE: Self

CAMERA_CAP_FLAGS_HAS_TRACKING_RECTANGLE flag.

Camera supports tracking of a selection rectangle on the camera view.

pub const HAS_TRACKING_GEO_STATUS: Self

CAMERA_CAP_FLAGS_HAS_TRACKING_GEO_STATUS flag.

Camera supports tracking geo status (CAMERA_TRACKING_GEO_STATUS).

pub const HAS_THERMAL_RANGE: Self

CAMERA_CAP_FLAGS_HAS_THERMAL_RANGE flag.

Camera supports absolute thermal range (request CAMERA_THERMAL_RANGE with MAV_CMD_REQUEST_MESSAGE).

Source

impl CameraCapFlags

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u16

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u16) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u16) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u16) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl CameraCapFlags

pub const fn iter(&self) -> Iter<CameraCapFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<CameraCapFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.