pub struct HilSensorUpdatedFlags(/* private fields */);Expand description
MAVLink bitmask enum HIL_SENSOR_UPDATED_FLAGS for common dialect.
Flags in the HIL_SENSOR message indicate which fields have updated since the last message
Implementations
Sourceimpl HilSensorUpdatedFlags
impl HilSensorUpdatedFlags
Sourcepub const HIL_SENSOR_UPDATED_XACC: Self
pub const HIL_SENSOR_UPDATED_XACC: Self
HIL_SENSOR_UPDATED_XACC flag.
The value in the xacc field has been updated
Sourcepub const HIL_SENSOR_UPDATED_YACC: Self
pub const HIL_SENSOR_UPDATED_YACC: Self
HIL_SENSOR_UPDATED_YACC flag.
The value in the yacc field has been updated
Sourcepub const HIL_SENSOR_UPDATED_ZACC: Self
pub const HIL_SENSOR_UPDATED_ZACC: Self
HIL_SENSOR_UPDATED_ZACC flag.
The value in the zacc field has been updated
Sourcepub const HIL_SENSOR_UPDATED_XGYRO: Self
pub const HIL_SENSOR_UPDATED_XGYRO: Self
HIL_SENSOR_UPDATED_XGYRO flag.
The value in the xgyro field has been updated
Sourcepub const HIL_SENSOR_UPDATED_YGYRO: Self
pub const HIL_SENSOR_UPDATED_YGYRO: Self
HIL_SENSOR_UPDATED_YGYRO flag.
The value in the ygyro field has been updated
Sourcepub const HIL_SENSOR_UPDATED_ZGYRO: Self
pub const HIL_SENSOR_UPDATED_ZGYRO: Self
HIL_SENSOR_UPDATED_ZGYRO flag.
The value in the zgyro field has been updated
Sourcepub const HIL_SENSOR_UPDATED_XMAG: Self
pub const HIL_SENSOR_UPDATED_XMAG: Self
HIL_SENSOR_UPDATED_XMAG flag.
The value in the xmag field has been updated
Sourcepub const HIL_SENSOR_UPDATED_YMAG: Self
pub const HIL_SENSOR_UPDATED_YMAG: Self
HIL_SENSOR_UPDATED_YMAG flag.
The value in the ymag field has been updated
Sourcepub const HIL_SENSOR_UPDATED_ZMAG: Self
pub const HIL_SENSOR_UPDATED_ZMAG: Self
HIL_SENSOR_UPDATED_ZMAG flag.
The value in the zmag field has been updated
Sourcepub const HIL_SENSOR_UPDATED_ABS_PRESSURE: Self
pub const HIL_SENSOR_UPDATED_ABS_PRESSURE: Self
HIL_SENSOR_UPDATED_ABS_PRESSURE flag.
The value in the abs_pressure field has been updated
Sourcepub const HIL_SENSOR_UPDATED_DIFF_PRESSURE: Self
pub const HIL_SENSOR_UPDATED_DIFF_PRESSURE: Self
HIL_SENSOR_UPDATED_DIFF_PRESSURE flag.
The value in the diff_pressure field has been updated
Sourcepub const HIL_SENSOR_UPDATED_PRESSURE_ALT: Self
pub const HIL_SENSOR_UPDATED_PRESSURE_ALT: Self
HIL_SENSOR_UPDATED_PRESSURE_ALT flag.
The value in the pressure_alt field has been updated
Sourcepub const HIL_SENSOR_UPDATED_TEMPERATURE: Self
pub const HIL_SENSOR_UPDATED_TEMPERATURE: Self
HIL_SENSOR_UPDATED_TEMPERATURE flag.
The value in the temperature field has been updated
Sourcepub const HIL_SENSOR_UPDATED_RESET: Self
pub const HIL_SENSOR_UPDATED_RESET: Self
HIL_SENSOR_UPDATED_RESET flag.
Full reset of attitude/position/velocities/etc was performed in sim (Bit 31).
Sourceimpl HilSensorUpdatedFlags
impl HilSensorUpdatedFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl HilSensorUpdatedFlags
impl HilSensorUpdatedFlags
Sourcepub const fn iter(&self) -> Iter<HilSensorUpdatedFlags> ⓘ
pub const fn iter(&self) -> Iter<HilSensorUpdatedFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<HilSensorUpdatedFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<HilSensorUpdatedFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.