MavSysStatusSensor

Struct MavSysStatusSensor 

pub struct MavSysStatusSensor(/* private fields */);
MAVLink bitmask enum MAV_SYS_STATUS_SENSOR for common dialect.

These encode the sensors whose status is sent as part of the SYS_STATUS message.

Implementations

Source

impl MavSysStatusSensor

pub const _3D_GYRO: Self

MAV_SYS_STATUS_SENSOR_3D_GYRO flag.

0x01 3D gyro

pub const _3D_ACCEL: Self

MAV_SYS_STATUS_SENSOR_3D_ACCEL flag.

0x02 3D accelerometer

pub const _3D_MAG: Self

MAV_SYS_STATUS_SENSOR_3D_MAG flag.

0x04 3D magnetometer

pub const ABSOLUTE_PRESSURE: Self

MAV_SYS_STATUS_SENSOR_ABSOLUTE_PRESSURE flag.

0x08 absolute pressure

pub const DIFFERENTIAL_PRESSURE: Self

MAV_SYS_STATUS_SENSOR_DIFFERENTIAL_PRESSURE flag.

0x10 differential pressure

pub const GPS: Self

MAV_SYS_STATUS_SENSOR_GPS flag.

0x20 GPS

pub const OPTICAL_FLOW: Self

MAV_SYS_STATUS_SENSOR_OPTICAL_FLOW flag.

0x40 optical flow

pub const VISION_POSITION: Self

MAV_SYS_STATUS_SENSOR_VISION_POSITION flag.

0x80 computer vision position

pub const LASER_POSITION: Self

MAV_SYS_STATUS_SENSOR_LASER_POSITION flag.

0x100 laser based position

pub const EXTERNAL_GROUND_TRUTH: Self

MAV_SYS_STATUS_SENSOR_EXTERNAL_GROUND_TRUTH flag.

0x200 external ground truth (Vicon or Leica)

pub const ANGULAR_RATE_CONTROL: Self

MAV_SYS_STATUS_SENSOR_ANGULAR_RATE_CONTROL flag.

0x400 3D angular rate control

pub const ATTITUDE_STABILIZATION: Self

MAV_SYS_STATUS_SENSOR_ATTITUDE_STABILIZATION flag.

0x800 attitude stabilization

pub const YAW_POSITION: Self

MAV_SYS_STATUS_SENSOR_YAW_POSITION flag.

0x1000 yaw position

pub const Z_ALTITUDE_CONTROL: Self

MAV_SYS_STATUS_SENSOR_Z_ALTITUDE_CONTROL flag.

0x2000 z/altitude control

pub const XY_POSITION_CONTROL: Self

MAV_SYS_STATUS_SENSOR_XY_POSITION_CONTROL flag.

0x4000 x/y position control

pub const MOTOR_OUTPUTS: Self

MAV_SYS_STATUS_SENSOR_MOTOR_OUTPUTS flag.

0x8000 motor outputs / control

pub const RC_RECEIVER: Self

MAV_SYS_STATUS_SENSOR_RC_RECEIVER flag.

0x10000 RC receiver

pub const _3D_GYRO2: Self

MAV_SYS_STATUS_SENSOR_3D_GYRO2 flag.

0x20000 2nd 3D gyro

pub const _3D_ACCEL2: Self

MAV_SYS_STATUS_SENSOR_3D_ACCEL2 flag.

0x40000 2nd 3D accelerometer

pub const _3D_MAG2: Self

MAV_SYS_STATUS_SENSOR_3D_MAG2 flag.

0x80000 2nd 3D magnetometer

pub const MAV_SYS_STATUS_GEOFENCE: Self

MAV_SYS_STATUS_GEOFENCE flag.

0x100000 geofence

pub const MAV_SYS_STATUS_AHRS: Self

MAV_SYS_STATUS_AHRS flag.

0x200000 AHRS subsystem health

pub const MAV_SYS_STATUS_TERRAIN: Self

MAV_SYS_STATUS_TERRAIN flag.

0x400000 Terrain subsystem health

pub const MAV_SYS_STATUS_REVERSE_MOTOR: Self

MAV_SYS_STATUS_REVERSE_MOTOR flag.

0x800000 Motors are reversed

pub const MAV_SYS_STATUS_LOGGING: Self

MAV_SYS_STATUS_LOGGING flag.

0x1000000 Logging

pub const BATTERY: Self

MAV_SYS_STATUS_SENSOR_BATTERY flag.

0x2000000 Battery

pub const PROXIMITY: Self

MAV_SYS_STATUS_SENSOR_PROXIMITY flag.

0x4000000 Proximity

pub const SATCOM: Self

MAV_SYS_STATUS_SENSOR_SATCOM flag.

0x8000000 Satellite Communication

pub const MAV_SYS_STATUS_PREARM_CHECK: Self

MAV_SYS_STATUS_PREARM_CHECK flag.

0x10000000 pre-arm check status. Always healthy when armed

pub const MAV_SYS_STATUS_OBSTACLE_AVOIDANCE: Self

MAV_SYS_STATUS_OBSTACLE_AVOIDANCE flag.

0x20000000 Avoidance/collision prevention

pub const PROPULSION: Self

MAV_SYS_STATUS_SENSOR_PROPULSION flag.

0x40000000 propulsion (actuator, esc, motor or propellor)

pub const MAV_SYS_STATUS_EXTENSION_USED: Self

MAV_SYS_STATUS_EXTENSION_USED flag.

0x80000000 Extended bit-field are used for further sensor status bits (needs to be set in onboard_control_sensors_present only)

Source

impl MavSysStatusSensor

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl MavSysStatusSensor

pub const fn iter(&self) -> Iter<MavSysStatusSensor>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<MavSysStatusSensor>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.