CameraImageCaptured

Struct CameraImageCaptured 

pub struct CameraImageCaptured {
    pub time_boot_ms: u32,
    pub time_utc: u64,
    pub camera_id: u8,
    pub lat: i32,
    pub lon: i32,
    pub alt: i32,
    pub relative_alt: i32,
    pub q: [f32; 4],
    pub image_index: i32,
    pub capture_result: i8,
    pub file_url: [u8; 205],
}
MAVLink CAMERA_IMAGE_CAPTURED message.

The minimum supported MAVLink version is MAVLink 2.

Description

Information about a captured image. This is emitted every time a message is captured. MAV_CMD_REQUEST_MESSAGE can be used to (re)request this message for a specific sequence number or range of sequence numbers: MAV_CMD_REQUEST_MESSAGE.param2 indicates the sequence number the first image to send, or set to -1 to send the message for all sequence numbers. MAV_CMD_REQUEST_MESSAGE.param3 is used to specify a range of messages to send: set to 0 (default) to send just the the message for the sequence number in param 2, set to -1 to send the message for the sequence number in param 2 and all the following sequence numbers, set to the sequence number of the final message in the range.

Encoding/Decoding

Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for CameraImageCaptured (encoding) and [IntoPayload] (decoding) traits. These traits are implemented by Message proc macro.

Fields

time_boot_ms: u32

MAVLink field time_boot_ms.

Timestamp (time since system boot).

time_utc: u64

MAVLink field time_utc.

Timestamp (time since UNIX epoch) in UTC. 0 for unknown.

camera_id: u8

MAVLink field camera_id.

Camera id of a non-MAVLink camera attached to an autopilot (1-6). 0 if the component is a MAVLink camera (with its own component id). Field name is usually camera_device_id.

lat: i32

MAVLink field lat.

Latitude where image was taken

lon: i32

MAVLink field lon.

Longitude where capture was taken

alt: i32

MAVLink field alt.

Altitude (MSL) where image was taken

relative_alt: i32

MAVLink field relative_alt.

Altitude above ground

q: [f32; 4]

MAVLink field q.

Quaternion of camera orientation (w, x, y, z order, zero-rotation is 1, 0, 0, 0)

image_index: i32

MAVLink field image_index.

Zero based index of this image (i.e. a new image will have index CAMERA_CAPTURE_STATUS.image count -1)

capture_result: i8

MAVLink field capture_result.

Boolean indicating success (1) or failure (0) while capturing this image.

file_url: [u8; 205]

MAVLink field file_url.

URL of image taken. Either local storage or http://foo.jpg if camera provides an HTTP interface.

Implementations

Source

impl CameraImageCaptured

pub const ID: MessageId = 263u32

MavLink message ID.

pub const fn spec() -> MessageInfo

Returns specification for this message.

pub const fn message_id() -> MessageId

Message ID.

pub const fn crc_extra() -> CrcExtra

Message CRC_EXTRA.

Minimum supported MAVLink version for this message.