pub struct CellularConfig {
pub enable_lte: u8,
pub enable_pin: u8,
pub pin: [u8; 16],
pub new_pin: [u8; 16],
pub apn: [u8; 32],
pub puk: [u8; 16],
pub roaming: u8,
pub response: CellularConfigResponse,
}Expand description
MAVLink CELLULAR_CONFIG message.
The minimum supported MAVLink version is MAVLink 2.
Description
Configure cellular modems. This message is re-emitted as an acknowledgement by the modem. The message may also be explicitly requested using MAV_CMD_REQUEST_MESSAGE.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
CellularConfig (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
enable_lte: u8MAVLink field enable_lte.
Enable/disable LTE. 0: setting unchanged, 1: disabled, 2: enabled. Current setting when sent back as a response.
enable_pin: u8MAVLink field enable_pin.
Enable/disable PIN on the SIM card. 0: setting unchanged, 1: disabled, 2: enabled. Current setting when sent back as a response.
pin: [u8; 16]MAVLink field pin.
PIN sent to the SIM card. Blank when PIN is disabled. Empty when message is sent back as a response.
new_pin: [u8; 16]MAVLink field new_pin.
New PIN when changing the PIN. Blank to leave it unchanged. Empty when message is sent back as a response.
apn: [u8; 32]MAVLink field apn.
Name of the cellular APN. Blank to leave it unchanged. Current APN when sent back as a response.
puk: [u8; 16]MAVLink field puk.
Required PUK code in case the user failed to authenticate 3 times with the PIN. Empty when message is sent back as a response.
roaming: u8MAVLink field roaming.
Enable/disable roaming. 0: setting unchanged, 1: disabled, 2: enabled. Current setting when sent back as a response.
response: CellularConfigResponseMAVLink field response.
Message acceptance response (sent back to GS).
Implementations
Sourceimpl CellularConfig
impl CellularConfig
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.