pub struct ChangeOperatorControl {
pub target_system: u8,
pub control_request: u8,
pub version: u8,
pub passkey: [u8; 25],
}Expand description
MAVLink CHANGE_OPERATOR_CONTROL message.
Minimum supported MAVLink version is MAVLink 1.
Description
Request to control this MAV
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
ChangeOperatorControl (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
target_system: u8MAVLink field target_system.
System the GCS requests control for
control_request: u8MAVLink field control_request.
0: request control of this MAV, 1: Release control of this MAV
version: u8MAVLink field version.
0: key as plaintext, 1-255: future, different hashing/encryption variants. The GCS should in general use the safest mode possible initially and then gradually move down the encryption level if it gets a NACK message indicating an encryption mismatch.
passkey: [u8; 25]MAVLink field passkey.
Password / Key, depending on version plaintext or encrypted. 25 or less characters, NULL terminated. The characters may involve A-Z, a-z, 0-9, and “!?,.-”
Implementations
Sourceimpl ChangeOperatorControl
impl ChangeOperatorControl
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.