pub struct ComponentInformation {
pub time_boot_ms: u32,
pub general_metadata_file_crc: u32,
pub general_metadata_uri: [u8; 100],
pub peripherals_metadata_file_crc: u32,
pub peripherals_metadata_uri: [u8; 100],
}Expand description
MAVLink COMPONENT_INFORMATION message.
The minimum supported MAVLink version is MAVLink 2.
Description
Component information message, which may be requested using MAV_CMD_REQUEST_MESSAGE.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
ComponentInformation (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
time_boot_ms: u32MAVLink field time_boot_ms.
Timestamp (time since system boot).
general_metadata_file_crc: u32MAVLink field general_metadata_file_crc.
CRC32 of the general metadata file (general_metadata_uri).
general_metadata_uri: [u8; 100]MAVLink field general_metadata_uri.
MAVLink FTP URI for the general metadata file (COMP_METADATA_TYPE_GENERAL), which may be compressed with xz. The file contains general component metadata, and may contain URI links for additional metadata (see COMP_METADATA_TYPE). The information is static from boot, and may be generated at compile time. The string needs to be zero terminated.
peripherals_metadata_file_crc: u32MAVLink field peripherals_metadata_file_crc.
CRC32 of peripherals metadata file (peripherals_metadata_uri).
peripherals_metadata_uri: [u8; 100]MAVLink field peripherals_metadata_uri.
(Optional) MAVLink FTP URI for the peripherals metadata file (COMP_METADATA_TYPE_PERIPHERALS), which may be compressed with xz. This contains data about “attached components” such as UAVCAN nodes. The peripherals are in a separate file because the information must be generated dynamically at runtime. The string needs to be zero terminated.
Implementations
Sourceimpl ComponentInformation
impl ComponentInformation
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.