pub struct CurrentMode {
pub standard_mode: MavStandardMode,
pub custom_mode: u32,
pub intended_custom_mode: u32,
}Expand description
MAVLink CURRENT_MODE message.
The minimum supported MAVLink version is MAVLink 2.
Description
Get the current mode. This should be emitted on any mode change, and broadcast at low rate (nominally 0.5 Hz). It may be requested using MAV_CMD_REQUEST_MESSAGE. See https://mavlink.io/en/services/standard_modes.html
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
CurrentMode (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
standard_mode: MavStandardModeMAVLink field standard_mode.
Standard mode.
custom_mode: u32MAVLink field custom_mode.
A bitfield for use for autopilot-specific flags
intended_custom_mode: u32MAVLink field intended_custom_mode.
The custom_mode of the mode that was last commanded by the user (for example, with MAV_CMD_DO_SET_STANDARD_MODE, MAV_CMD_DO_SET_MODE or via RC). This should usually be the same as custom_mode. It will be different if the vehicle is unable to enter the intended mode, or has left that mode due to a failsafe condition. 0 indicates the intended custom mode is unknown/not supplied
Implementations
Sourceimpl CurrentMode
impl CurrentMode
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.