pub struct DebugFloatArray {
pub time_usec: u64,
pub name: [u8; 10],
pub array_id: u16,
pub data: [f32; 58],
}Expand description
MAVLink DEBUG_FLOAT_ARRAY message.
The minimum supported MAVLink version is MAVLink 2.
Description
Large debug/prototyping array. The message uses the maximum available payload for data. The array_id and name fields are used to discriminate between messages in code and in user interfaces (respectively). Do not use in production code.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
DebugFloatArray (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
time_usec: u64MAVLink field time_usec.
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
name: [u8; 10]MAVLink field name.
Name, for human-friendly display in a Ground Control Station
array_id: u16MAVLink field array_id.
Unique ID used to discriminate between arrays
data: [f32; 58]MAVLink field data.
data
Implementations
Sourceimpl DebugFloatArray
impl DebugFloatArray
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.