Struct LocalPositionNedSystemGlobalOffset

pub struct LocalPositionNedSystemGlobalOffset {
    pub time_boot_ms: u32,
    pub x: f32,
    pub y: f32,
    pub z: f32,
    pub roll: f32,
    pub pitch: f32,
    pub yaw: f32,
}
MAVLink LOCAL_POSITION_NED_SYSTEM_GLOBAL_OFFSET message.

Minimum supported MAVLink version is MAVLink 1.

Description

The offset in X, Y, Z and yaw between the LOCAL_POSITION_NED messages of MAV X and the global coordinate frame in NED coordinates. Coordinate frame is right-handed, Z-axis down (aeronautical frame, NED / north-east-down convention)

Encoding/Decoding

Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for LocalPositionNedSystemGlobalOffset (encoding) and [IntoPayload] (decoding) traits. These traits are implemented by Message proc macro.

Fields

time_boot_ms: u32

MAVLink field time_boot_ms.

Timestamp (time since system boot).

x: f32

MAVLink field x.

X Position

y: f32

MAVLink field y.

Y Position

z: f32

MAVLink field z.

Z Position

roll: f32

MAVLink field roll.

Roll

pitch: f32

MAVLink field pitch.

Pitch

yaw: f32

MAVLink field yaw.

Yaw

Implementations

Source

impl LocalPositionNedSystemGlobalOffset

pub const ID: MessageId = 89u32

MavLink message ID.

pub const fn spec() -> MessageInfo

Returns specification for this message.

pub const fn message_id() -> MessageId

Message ID.

pub const fn crc_extra() -> CrcExtra

Message CRC_EXTRA.

Minimum supported MAVLink version for this message.