ManualControl

Struct ManualControl 

pub struct ManualControl {
Show 16 fields pub target: u8, pub x: i16, pub y: i16, pub z: i16, pub r: i16, pub buttons: u16, pub buttons2: u16, pub enabled_extensions: u8, pub s: i16, pub t: i16, pub aux1: i16, pub aux2: i16, pub aux3: i16, pub aux4: i16, pub aux5: i16, pub aux6: i16,
}
MAVLink MANUAL_CONTROL message.

The minimum supported MAVLink version is MAVLink 1.

Description

This message provides an API for manually controlling the vehicle using standard joystick axes nomenclature, along with a joystick-like input device. Unused axes can be disabled and buttons states are transmitted as individual on/off bits of a bitmask

Encoding/Decoding

Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for ManualControl (encoding) and [IntoPayload] (decoding) traits. These traits are implemented by Message proc macro.

Fields

target: u8

MAVLink field target.

The system to be controlled.

x: i16

MAVLink field x.

X-axis, normalized to the range [-1000,1000]. A value of INT16_MAX indicates that this axis is invalid. Generally corresponds to forward(1000)-backward(-1000) movement on a joystick and the pitch of a vehicle.

y: i16

MAVLink field y.

Y-axis, normalized to the range [-1000,1000]. A value of INT16_MAX indicates that this axis is invalid. Generally corresponds to left(-1000)-right(1000) movement on a joystick and the roll of a vehicle.

z: i16

MAVLink field z.

Z-axis, normalized to the range [-1000,1000]. A value of INT16_MAX indicates that this axis is invalid. Generally corresponds to a separate slider movement with maximum being 1000 and minimum being -1000 on a joystick and the thrust of a vehicle. Positive values are positive thrust, negative values are negative thrust.

r: i16

MAVLink field r.

R-axis, normalized to the range [-1000,1000]. A value of INT16_MAX indicates that this axis is invalid. Generally corresponds to a twisting of the joystick, with counter-clockwise being 1000 and clockwise being -1000, and the yaw of a vehicle.

buttons: u16

MAVLink field buttons.

A bitfield corresponding to the joystick buttons’ 0-15 current state, 1 for pressed, 0 for released. The lowest bit corresponds to Button 1.

buttons2: u16

MAVLink field buttons2.

A bitfield corresponding to the joystick buttons’ 16-31 current state, 1 for pressed, 0 for released. The lowest bit corresponds to Button 16.

enabled_extensions: u8

MAVLink field enabled_extensions.

Set bits to 1 to indicate which of the following extension fields contain valid data: bit 0: pitch, bit 1: roll, bit 2: aux1, bit 3: aux2, bit 4: aux3, bit 5: aux4, bit 6: aux5, bit 7: aux6

s: i16

MAVLink field s.

Pitch-only-axis, normalized to the range [-1000,1000]. Generally corresponds to pitch on vehicles with additional degrees of freedom. Valid if bit 0 of enabled_extensions field is set. Set to 0 if invalid.

t: i16

MAVLink field t.

Roll-only-axis, normalized to the range [-1000,1000]. Generally corresponds to roll on vehicles with additional degrees of freedom. Valid if bit 1 of enabled_extensions field is set. Set to 0 if invalid.

aux1: i16

MAVLink field aux1.

Aux continuous input field 1. Normalized in the range [-1000,1000]. Purpose defined by recipient. Valid data if bit 2 of enabled_extensions field is set. 0 if bit 2 is unset.

aux2: i16

MAVLink field aux2.

Aux continuous input field 2. Normalized in the range [-1000,1000]. Purpose defined by recipient. Valid data if bit 3 of enabled_extensions field is set. 0 if bit 3 is unset.

aux3: i16

MAVLink field aux3.

Aux continuous input field 3. Normalized in the range [-1000,1000]. Purpose defined by recipient. Valid data if bit 4 of enabled_extensions field is set. 0 if bit 4 is unset.

aux4: i16

MAVLink field aux4.

Aux continuous input field 4. Normalized in the range [-1000,1000]. Purpose defined by recipient. Valid data if bit 5 of enabled_extensions field is set. 0 if bit 5 is unset.

aux5: i16

MAVLink field aux5.

Aux continuous input field 5. Normalized in the range [-1000,1000]. Purpose defined by recipient. Valid data if bit 6 of enabled_extensions field is set. 0 if bit 6 is unset.

aux6: i16

MAVLink field aux6.

Aux continuous input field 6. Normalized in the range [-1000,1000]. Purpose defined by recipient. Valid data if bit 7 of enabled_extensions field is set. 0 if bit 7 is unset.

Implementations

Source

impl ManualControl

pub const ID: MessageId = 69u32

MavLink message ID.

pub const fn spec() -> MessageInfo

Returns specification for this message.

pub const fn message_id() -> MessageId

Message ID.

pub const fn crc_extra() -> CrcExtra

Message CRC_EXTRA.

Minimum supported MAVLink version for this message.