pub struct MemoryVect {
pub address: u16,
pub ver: u8,
pub type_: u8,
pub value: [i8; 32],
}Expand description
MAVLink MEMORY_VECT message.
Minimum supported MAVLink version is MAVLink 1.
Description
Send raw controller memory. The use of this message is discouraged for normal packets, but a quite efficient way for testing new messages and getting experimental debug output.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
MemoryVect (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
address: u16MAVLink field address.
Starting address of the debug variables
ver: u8MAVLink field ver.
Version code of the type variable. 0=unknown, type ignored and assumed int16_t. 1=as below
type_: u8MAVLink field type.
Type code of the memory variables. for ver = 1: 0=16 x int16_t, 1=16 x uint16_t, 2=16 x Q15, 3=16 x 1Q14
value: [i8; 32]MAVLink field value.
Memory contents at specified address
Implementations
Sourceimpl MemoryVect
impl MemoryVect
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.