pub struct MissionRequestInt {
pub target_system: u8,
pub target_component: u8,
pub seq: u16,
pub mission_type: MavMissionType,
}Expand description
MAVLink MISSION_REQUEST_INT message.
The minimum supported MAVLink version is MAVLink 1.
Description
Request the information of the mission item with the sequence number seq. The response of the system to this message should be a MISSION_ITEM_INT message. https://mavlink.io/en/services/mission.html
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
MissionRequestInt (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
target_system: u8MAVLink field target_system.
System ID
target_component: u8MAVLink field target_component.
Component ID
seq: u16MAVLink field seq.
Sequence
mission_type: MavMissionTypeMAVLink field mission_type.
Mission type.
Implementations
Sourceimpl MissionRequestInt
impl MissionRequestInt
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.