ParamExtSet

Struct ParamExtSet 

pub struct ParamExtSet {
    pub target_system: u8,
    pub target_component: u8,
    pub param_id: [u8; 16],
    pub param_value: [u8; 128],
    pub param_type: MavParamExtType,
}
MAVLink PARAM_EXT_SET message.

The minimum supported MAVLink version is MAVLink 2.

Description

Set a parameter value. In order to deal with message loss (and retransmission of PARAM_EXT_SET), when setting a parameter value and the new value is the same as the current value, you will immediately get a PARAM_ACK_ACCEPTED response. If the current state is PARAM_ACK_IN_PROGRESS, you will accordingly receive a PARAM_ACK_IN_PROGRESS in response.

Encoding/Decoding

Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for ParamExtSet (encoding) and [IntoPayload] (decoding) traits. These traits are implemented by Message proc macro.

Fields

target_system: u8

MAVLink field target_system.

System ID

target_component: u8

MAVLink field target_component.

Component ID

param_id: [u8; 16]

MAVLink field param_id.

Parameter id, terminated by NULL if the length is less than 16 human-readable chars and WITHOUT null termination (NULL) byte if the length is exactly 16 chars - applications have to provide 16+1 bytes storage if the ID is stored as string

param_value: [u8; 128]

MAVLink field param_value.

Parameter value

param_type: MavParamExtType

MAVLink field param_type.

Parameter type.

Implementations

Source

impl ParamExtSet

pub const ID: MessageId = 323u32

MavLink message ID.

pub const fn spec() -> MessageInfo

Returns specification for this message.

pub const fn message_id() -> MessageId

Message ID.

pub const fn crc_extra() -> CrcExtra

Message CRC_EXTRA.

Minimum supported MAVLink version for this message.