ResourceRequest

Struct ResourceRequest 

pub struct ResourceRequest {
    pub request_id: u8,
    pub uri_type: u8,
    pub uri: [u8; 120],
    pub transfer_type: u8,
    pub storage: [u8; 120],
}
MAVLink RESOURCE_REQUEST message.

The minimum supported MAVLink version is MAVLink 1.

Description

The autopilot is requesting a resource (file, binary, other type of data)

Encoding/Decoding

Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for ResourceRequest (encoding) and [IntoPayload] (decoding) traits. These traits are implemented by Message proc macro.

Fields

request_id: u8

MAVLink field request_id.

Request ID. This ID should be re-used when sending back URI contents

uri_type: u8

MAVLink field uri_type.

The type of requested URI. 0 = a file via URL. 1 = a UAVCAN binary

uri: [u8; 120]

MAVLink field uri.

The requested unique resource identifier (URI). It is not necessarily a straight domain name (depends on the URI type enum)

transfer_type: u8

MAVLink field transfer_type.

The way the autopilot wants to receive the URI. 0 = MAVLink FTP. 1 = binary stream.

storage: [u8; 120]

MAVLink field storage.

The storage path the autopilot wants the URI to be stored in. Will only be valid if the transfer_type has a storage associated (e.g. MAVLink FTP).

Implementations

Source

impl ResourceRequest

pub const ID: MessageId = 142u32

MavLink message ID.

pub const fn spec() -> MessageInfo

Returns specification for this message.

pub const fn message_id() -> MessageId

Message ID.

pub const fn crc_extra() -> CrcExtra

Message CRC_EXTRA.

Minimum supported MAVLink version for this message.