SetActuatorControlTarget

Struct SetActuatorControlTarget 

pub struct SetActuatorControlTarget {
    pub time_usec: u64,
    pub group_mlx: u8,
    pub target_system: u8,
    pub target_component: u8,
    pub controls: [f32; 8],
}
MAVLink SET_ACTUATOR_CONTROL_TARGET message.

The minimum supported MAVLink version is MAVLink 1.

Description

Set the vehicle attitude and body angular rates.

Encoding/Decoding

Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for SetActuatorControlTarget (encoding) and [IntoPayload] (decoding) traits. These traits are implemented by Message proc macro.

Fields

time_usec: u64

MAVLink field time_usec.

Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.

group_mlx: u8

MAVLink field group_mlx.

Actuator group. The “_mlx” indicates this is a multi-instance message and a MAVLink parser should use this field to difference between instances.

target_system: u8

MAVLink field target_system.

System ID

target_component: u8

MAVLink field target_component.

Component ID

controls: [f32; 8]

MAVLink field controls.

Actuator controls. Normed to -1..+1 where 0 is neutral position. Throttle for single rotation direction motors is 0..1, negative range for reverse direction. Standard mapping for attitude controls (group 0): (index 0-7): roll, pitch, yaw, throttle, flaps, spoilers, airbrakes, landing gear. Load a pass-through mixer to repurpose them as generic outputs.

Implementations

Source

impl SetActuatorControlTarget

pub const ID: MessageId = 139u32

MavLink message ID.

pub const fn spec() -> MessageInfo

Returns specification for this message.

pub const fn message_id() -> MessageId

Message ID.

pub const fn crc_extra() -> CrcExtra

Message CRC_EXTRA.

Minimum supported MAVLink version for this message.