pub struct SetPositionTargetLocalNed {Show 16 fields
pub time_boot_ms: u32,
pub target_system: u8,
pub target_component: u8,
pub coordinate_frame: MavFrame,
pub type_mask: PositionTargetTypemask,
pub x: f32,
pub y: f32,
pub z: f32,
pub vx: f32,
pub vy: f32,
pub vz: f32,
pub afx: f32,
pub afy: f32,
pub afz: f32,
pub yaw: f32,
pub yaw_rate: f32,
}Expand description
MAVLink SET_POSITION_TARGET_LOCAL_NED message.
Minimum supported MAVLink version is MAVLink 1.
Description
Sets a desired vehicle position in a local north-east-down coordinate frame. Used by an external controller to command the vehicle (manual controller or other system).
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
SetPositionTargetLocalNed (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
time_boot_ms: u32MAVLink field time_boot_ms.
Timestamp (time since system boot).
target_system: u8MAVLink field target_system.
System ID
target_component: u8MAVLink field target_component.
Component ID
coordinate_frame: MavFrameMAVLink field coordinate_frame.
Valid options are: MAV_FRAME_LOCAL_NED = 1, MAV_FRAME_LOCAL_OFFSET_NED = 7, MAV_FRAME_BODY_NED = 8, MAV_FRAME_BODY_OFFSET_NED = 9
type_mask: PositionTargetTypemaskMAVLink field type_mask.
Bitmap to indicate which dimensions should be ignored by the vehicle.
x: f32MAVLink field x.
X Position in NED frame
y: f32MAVLink field y.
Y Position in NED frame
z: f32MAVLink field z.
Z Position in NED frame (note, altitude is negative in NED)
vx: f32MAVLink field vx.
X velocity in NED frame
vy: f32MAVLink field vy.
Y velocity in NED frame
vz: f32MAVLink field vz.
Z velocity in NED frame
afx: f32MAVLink field afx.
X acceleration or force (if bit 10 of type_mask is set) in NED frame in meter / s^2 or N
afy: f32MAVLink field afy.
Y acceleration or force (if bit 10 of type_mask is set) in NED frame in meter / s^2 or N
afz: f32MAVLink field afz.
Z acceleration or force (if bit 10 of type_mask is set) in NED frame in meter / s^2 or N
yaw: f32MAVLink field yaw.
yaw setpoint
yaw_rate: f32MAVLink field yaw_rate.
yaw rate setpoint
Implementations
Sourceimpl SetPositionTargetLocalNed
impl SetPositionTargetLocalNed
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.