pub struct SystemTime {
pub time_unix_usec: u64,
pub time_boot_ms: u32,
}Expand description
MAVLink SYSTEM_TIME message.
The minimum supported MAVLink version is MAVLink 1.
Description
The system time is the time of the master clock. This can be emitted by flight controllers, onboard computers, or other components in the MAVLink network. Components that are using a less reliable time source, such as a battery-backed real time clock, can choose to match their system clock to that of a SYSTEM_TYPE that indicates a more recent time. This allows more broadly accurate date stamping of logs, and so on. If precise time synchronization is needed then use TIMESYNC instead.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
SystemTime (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
time_unix_usec: u64MAVLink field time_unix_usec.
Timestamp (UNIX epoch time).
time_boot_ms: u32MAVLink field time_boot_ms.
Timestamp (time since system boot).
Implementations
Sourceimpl SystemTime
impl SystemTime
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.