TimeEstimateToTarget

Struct TimeEstimateToTarget 

pub struct TimeEstimateToTarget {
    pub safe_return: i32,
    pub land: i32,
    pub mission_next_item: i32,
    pub mission_end: i32,
    pub commanded_action: i32,
}
MAVLink TIME_ESTIMATE_TO_TARGET message.

The minimum supported MAVLink version is MAVLink 2.

Description

Time/duration estimates for various events and actions given the current vehicle state and position.

Encoding/Decoding

Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for TimeEstimateToTarget (encoding) and [IntoPayload] (decoding) traits. These traits are implemented by Message proc macro.

Fields

safe_return: i32

MAVLink field safe_return.

Estimated time to complete the vehicle’s configured “safe return” action from its current position (e.g. RTL, Smart RTL, etc.). -1 indicates that the vehicle is landed, or that no time estimate available.

land: i32

MAVLink field land.

Estimated time for vehicle to complete the LAND action from its current position. -1 indicates that the vehicle is landed, or that no time estimate available.

mission_next_item: i32

MAVLink field mission_next_item.

Estimated time for reaching/completing the currently active mission item. -1 means no time estimate available.

mission_end: i32

MAVLink field mission_end.

Estimated time for completing the current mission. -1 means no mission active and/or no estimate available.

commanded_action: i32

MAVLink field commanded_action.

Estimated time for completing the current commanded action (i.e. Go To, Takeoff, Land, etc.). -1 means no action active and/or no estimate available.

Implementations

Source

impl TimeEstimateToTarget

pub const ID: MessageId = 380u32

MavLink message ID.

pub const fn spec() -> MessageInfo

Returns specification for this message.

pub const fn message_id() -> MessageId

Message ID.

pub const fn crc_extra() -> CrcExtra

Message CRC_EXTRA.

Minimum supported MAVLink version for this message.