TargetObsFrame

Enum TargetObsFrame 

#[repr(u8)]
pub enum TargetObsFrame { LocalNed = 0, BodyFrd = 1, LocalOffsetNed = 2, Other = 3, }
MAVLink enum TARGET_OBS_FRAME for development dialect.

The frame of a target observation from an onboard sensor.

Variants



LocalNed = 0

MAVLink enum entry TARGET_OBS_FRAME_LOCAL_NED.

NED local tangent frame (x: North, y: East, z: Down) with origin fixed relative to earth.



BodyFrd = 1

MAVLink enum entry TARGET_OBS_FRAME_BODY_FRD.

FRD local frame aligned to the vehicle’s attitude (x: Forward, y: Right, z: Down) with an origin that travels with vehicle.



LocalOffsetNed = 2

MAVLink enum entry TARGET_OBS_FRAME_LOCAL_OFFSET_NED.

NED local tangent frame (x: North, y: East, z: Down) with an origin that travels with vehicle.



Other = 3

MAVLink enum entry TARGET_OBS_FRAME_OTHER.

Other sensor frame for target observations neither in local NED nor in body FRD.

Implementations

Source

impl TargetObsFrame

pub fn name() -> &'static str

Returns a canonical MAVLink name

pub fn entries() -> impl Iterator<Item = Self>

Iterator over all entries within this enum.

Requires metadata feature flag to be enabled.

pub fn value(&self) -> u8

Returns value of this enum variant.

Requires metadata feature flag to be enabled.