pub struct TargetAbsolute {Show 13 fields
pub timestamp: u64,
pub id: u8,
pub sensor_capabilities: TargetAbsoluteSensorCapabilityFlags,
pub lat: i32,
pub lon: i32,
pub alt: f32,
pub vel: [f32; 3],
pub acc: [f32; 3],
pub q_target: [f32; 4],
pub rates: [f32; 3],
pub position_std: [f32; 2],
pub vel_std: [f32; 3],
pub acc_std: [f32; 3],
}Expand description
MAVLink TARGET_ABSOLUTE message.
The minimum supported MAVLink version is MAVLink 2.
Description
Current motion information from sensors on a target
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
TargetAbsolute (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
timestamp: u64MAVLink field timestamp.
Timestamp (UNIX epoch time).
id: u8MAVLink field id.
The ID of the target if multiple targets are present
sensor_capabilities: TargetAbsoluteSensorCapabilityFlagsMAVLink field sensor_capabilities.
Bitmap to indicate the sensor’s reporting capabilities
lat: i32MAVLink field lat.
Target’s latitude (WGS84)
lon: i32MAVLink field lon.
Target’s longitude (WGS84)
alt: f32MAVLink field alt.
Target’s altitude (AMSL)
vel: [f32; 3]MAVLink field vel.
Target’s velocity in its body frame
acc: [f32; 3]MAVLink field acc.
Linear target’s acceleration in its body frame
q_target: [f32; 4]MAVLink field q_target.
Quaternion of the target’s orientation from its body frame to the vehicle’s NED frame.
rates: [f32; 3]MAVLink field rates.
Target’s roll, pitch and yaw rates
position_std: [f32; 2]MAVLink field position_std.
Standard deviation of horizontal (eph) and vertical (epv) position errors
vel_std: [f32; 3]MAVLink field vel_std.
Standard deviation of the target’s velocity in its body frame
acc_std: [f32; 3]MAVLink field acc_std.
Standard deviation of the target’s acceleration in its body frame
Implementations
Sourceimpl TargetAbsolute
impl TargetAbsolute
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.