ResourceRequest

Type Alias ResourceRequest 

pub type ResourceRequest = ResourceRequest;
Originally defined in common::messages::resource_request.

Aliased Type

pub struct ResourceRequest {
    pub request_id: u8,
    pub uri_type: u8,
    pub uri: [u8; 120],
    pub transfer_type: u8,
    pub storage: [u8; 120],
}

Fields

request_id: u8

MAVLink field request_id.

Request ID. This ID should be re-used when sending back URI contents

uri_type: u8

MAVLink field uri_type.

The type of requested URI. 0 = a file via URL. 1 = a UAVCAN binary

uri: [u8; 120]

MAVLink field uri.

The requested unique resource identifier (URI). It is not necessarily a straight domain name (depends on the URI type enum)

transfer_type: u8

MAVLink field transfer_type.

The way the autopilot wants to receive the URI. 0 = MAVLink FTP. 1 = binary stream.

storage: [u8; 120]

MAVLink field storage.

The storage path the autopilot wants the URI to be stored in. Will only be valid if the transfer_type has a storage associated (e.g. MAVLink FTP).