pub type DigicamControl = DigicamControl;Expand description
Originally defined in ardupilotmega::messages::digicam_control.
Aliased Type
struct DigicamControl {
pub target_system: u8,
pub target_component: u8,
pub session: u8,
pub zoom_pos: u8,
pub zoom_step: i8,
pub focus_lock: u8,
pub shot: u8,
pub command_id: u8,
pub extra_param: u8,
pub extra_value: f32,
}Fields
target_system: u8MAVLink field target_system.
System ID.
target_component: u8MAVLink field target_component.
Component ID.
session: u8MAVLink field session.
0: stop, 1: start or keep it up //Session control e.g. show/hide lens.
zoom_pos: u8MAVLink field zoom_pos.
1 to N //Zoom’s absolute position (0 means ignore).
zoom_step: i8MAVLink field zoom_step.
-100 to 100 //Zooming step value to offset zoom from the current position.
focus_lock: u8MAVLink field focus_lock.
0: unlock focus or keep unlocked, 1: lock focus or keep locked, 3: re-lock focus.
shot: u8MAVLink field shot.
0: ignore, 1: shot or start filming.
command_id: u8MAVLink field command_id.
Command Identity (incremental loop: 0 to 255)//A command sent multiple times will be executed or pooled just once.
extra_param: u8MAVLink field extra_param.
Extra parameters enumeration (0 means ignore).
extra_value: f32MAVLink field extra_value.
Correspondent value to given extra_param.