pub type GlobalPositionIntCov = GlobalPositionIntCov;Expand description
Originally defined in common::messages::global_position_int_cov.
Aliased Type
pub struct GlobalPositionIntCov {
pub time_usec: u64,
pub estimator_type: MavEstimatorType,
pub lat: i32,
pub lon: i32,
pub alt: i32,
pub relative_alt: i32,
pub vx: f32,
pub vy: f32,
pub vz: f32,
pub covariance: [f32; 36],
}Fields
time_usec: u64MAVLink field time_usec.
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
estimator_type: MavEstimatorTypeMAVLink field estimator_type.
Class id of the estimator this estimate originated from.
lat: i32MAVLink field lat.
Latitude
lon: i32MAVLink field lon.
Longitude
alt: i32MAVLink field alt.
Altitude in meters above MSL
relative_alt: i32MAVLink field relative_alt.
Altitude above ground
vx: f32MAVLink field vx.
Ground X Speed (Latitude)
vy: f32MAVLink field vy.
Ground Y Speed (Longitude)
vz: f32MAVLink field vz.
Ground Z Speed (Altitude)
covariance: [f32; 36]MAVLink field covariance.
Row-major representation of a 6x6 position and velocity 6x6 cross-covariance matrix (states: lat, lon, alt, vx, vy, vz; first six entries are the first ROW, next six entries are the second row, etc.). If unknown, assign NaN value to first element in the array.