Type Alias OpenDroneIdSystem

pub type OpenDroneIdSystem = OpenDroneIdSystem;
Aliased Type

struct OpenDroneIdSystem {
Show 15 fields pub target_system: u8, pub target_component: u8, pub id_or_mac: [u8; 20], pub operator_location_type: MavOdidOperatorLocationType, pub classification_type: MavOdidClassificationType, pub operator_latitude: i32, pub operator_longitude: i32, pub area_count: u16, pub area_radius: u16, pub area_ceiling: f32, pub area_floor: f32, pub category_eu: MavOdidCategoryEu, pub class_eu: MavOdidClassEu, pub operator_altitude_geo: f32, pub timestamp: u32,
}

Fields

target_system: u8

MAVLink field target_system.

System ID (0 for broadcast).

target_component: u8

MAVLink field target_component.

Component ID (0 for broadcast).

id_or_mac: [u8; 20]

MAVLink field id_or_mac.

Only used for drone ID data received from other UAs. See detailed description at https://mavlink.io/en/services/opendroneid.html.

operator_location_type: MavOdidOperatorLocationType

MAVLink field operator_location_type.

Specifies the operator location type.

classification_type: MavOdidClassificationType

MAVLink field classification_type.

Specifies the classification type of the UA.

operator_latitude: i32

MAVLink field operator_latitude.

Latitude of the operator. If unknown: 0 (both Lat/Lon).

operator_longitude: i32

MAVLink field operator_longitude.

Longitude of the operator. If unknown: 0 (both Lat/Lon).

area_count: u16

MAVLink field area_count.

Number of aircraft in the area, group or formation (default 1). Used only for swarms/multiple UA.

area_radius: u16

MAVLink field area_radius.

Radius of the cylindrical area of the group or formation (default 0). Used only for swarms/multiple UA.

area_ceiling: f32

MAVLink field area_ceiling.

Area Operations Ceiling relative to WGS84. If unknown: -1000 m. Used only for swarms/multiple UA.

area_floor: f32

MAVLink field area_floor.

Area Operations Floor relative to WGS84. If unknown: -1000 m. Used only for swarms/multiple UA.

category_eu: MavOdidCategoryEu

MAVLink field category_eu.

When classification_type is MAV_ODID_CLASSIFICATION_TYPE_EU, specifies the category of the UA.

class_eu: MavOdidClassEu

MAVLink field class_eu.

When classification_type is MAV_ODID_CLASSIFICATION_TYPE_EU, specifies the class of the UA.

operator_altitude_geo: f32

MAVLink field operator_altitude_geo.

Geodetic altitude of the operator relative to WGS84. If unknown: -1000 m.

timestamp: u32

MAVLink field timestamp.

32 bit Unix Timestamp in seconds since 00:00:00 01/01/2019.