pub type SimState = SimState;Expand description
Originally defined in common::messages::sim_state.
Aliased Type
pub struct SimState {Show 23 fields
pub q1: f32,
pub q2: f32,
pub q3: f32,
pub q4: f32,
pub roll: f32,
pub pitch: f32,
pub yaw: f32,
pub xacc: f32,
pub yacc: f32,
pub zacc: f32,
pub xgyro: f32,
pub ygyro: f32,
pub zgyro: f32,
pub lat: f32,
pub lon: f32,
pub alt: f32,
pub std_dev_horz: f32,
pub std_dev_vert: f32,
pub vn: f32,
pub ve: f32,
pub vd: f32,
pub lat_int: i32,
pub lon_int: i32,
}Fields
q1: f32MAVLink field q1.
True attitude quaternion component 1, w (1 in null-rotation)
q2: f32MAVLink field q2.
True attitude quaternion component 2, x (0 in null-rotation)
q3: f32MAVLink field q3.
True attitude quaternion component 3, y (0 in null-rotation)
q4: f32MAVLink field q4.
True attitude quaternion component 4, z (0 in null-rotation)
roll: f32MAVLink field roll.
Attitude roll expressed as Euler angles, not recommended except for human-readable outputs
pitch: f32MAVLink field pitch.
Attitude pitch expressed as Euler angles, not recommended except for human-readable outputs
yaw: f32MAVLink field yaw.
Attitude yaw expressed as Euler angles, not recommended except for human-readable outputs
xacc: f32MAVLink field xacc.
X acceleration
yacc: f32MAVLink field yacc.
Y acceleration
zacc: f32MAVLink field zacc.
Z acceleration
xgyro: f32MAVLink field xgyro.
Angular speed around X axis
ygyro: f32MAVLink field ygyro.
Angular speed around Y axis
zgyro: f32MAVLink field zgyro.
Angular speed around Z axis
lat: f32MAVLink field lat.
Latitude (lower precision). Both this and the lat_int field should be set.
lon: f32MAVLink field lon.
Longitude (lower precision). Both this and the lon_int field should be set.
alt: f32MAVLink field alt.
Altitude
std_dev_horz: f32MAVLink field std_dev_horz.
Horizontal position standard deviation
std_dev_vert: f32MAVLink field std_dev_vert.
Vertical position standard deviation
vn: f32MAVLink field vn.
True velocity in north direction in earth-fixed NED frame
ve: f32MAVLink field ve.
True velocity in east direction in earth-fixed NED frame
vd: f32MAVLink field vd.
True velocity in down direction in earth-fixed NED frame
lat_int: i32MAVLink field lat_int.
Latitude (higher precision). If 0, recipients should use the lat field value (otherwise this field is preferred).
lon_int: i32MAVLink field lon_int.
Longitude (higher precision). If 0, recipients should use the lon field value (otherwise this field is preferred).