pub type TimeEstimateToTarget = TimeEstimateToTarget;Expand description
Originally defined in common::messages::time_estimate_to_target.
Aliased Type
pub struct TimeEstimateToTarget {
pub safe_return: i32,
pub land: i32,
pub mission_next_item: i32,
pub mission_end: i32,
pub commanded_action: i32,
}Fields
safe_return: i32MAVLink field safe_return.
Estimated time to complete the vehicle’s configured “safe return” action from its current position (e.g. RTL, Smart RTL, etc.). -1 indicates that the vehicle is landed, or that no time estimate available.
land: i32MAVLink field land.
Estimated time for vehicle to complete the LAND action from its current position. -1 indicates that the vehicle is landed, or that no time estimate available.
mission_next_item: i32MAVLink field mission_next_item.
Estimated time for reaching/completing the currently active mission item. -1 means no time estimate available.
mission_end: i32MAVLink field mission_end.
Estimated time for completing the current mission. -1 means no mission active and/or no estimate available.
commanded_action: i32MAVLink field commanded_action.
Estimated time for completing the current commanded action (i.e. Go To, Takeoff, Land, etc.). -1 means no action active and/or no estimate available.