Enum CompMetadataType

#[repr(u8)]
pub enum CompMetadataType { General = 0, Parameter = 1, Commands = 2, Peripherals = 3, Events = 4, Actuators = 5, }
MAVLink enum COMP_METADATA_TYPE for common dialect.

Supported component metadata types. These are used in the “general” metadata file returned by COMPONENT_METADATA to provide information about supported metadata types. The types are not used directly in MAVLink messages.

Variants



General = 0

MAVLink enum entry COMP_METADATA_TYPE_GENERAL.

General information about the component. General metadata includes information about other metadata types supported by the component. Files of this type must be supported, and must be downloadable from vehicle using a MAVLink FTP URI.



Parameter = 1

MAVLink enum entry COMP_METADATA_TYPE_PARAMETER.

Parameter meta data.



Commands = 2

MAVLink enum entry COMP_METADATA_TYPE_COMMANDS.

Meta data that specifies which commands and command parameters the vehicle supports. (WIP)



Peripherals = 3

MAVLink enum entry COMP_METADATA_TYPE_PERIPHERALS.

Meta data that specifies external non-MAVLink peripherals.



Events = 4

MAVLink enum entry COMP_METADATA_TYPE_EVENTS.

Meta data for the events interface.



Actuators = 5

MAVLink enum entry COMP_METADATA_TYPE_ACTUATORS.

Meta data for actuator configuration (motors, servos and vehicle geometry) and testing.

Implementations

Source

impl CompMetadataType

pub fn name() -> &'static str

Returns a canonical MAVLink name

pub fn entries() -> impl Iterator<Item = Self>

Iterator over all entries within this enum.

Requires metadata feature flag to be enabled.

pub fn value(&self) -> u8

Returns value of this enum variant.

Requires metadata feature flag to be enabled.