pub struct ComponentMetadata {
pub time_boot_ms: u32,
pub file_crc: u32,
pub uri: [u8; 100],
}Expand description
MAVLink COMPONENT_METADATA message.
Minimum supported MAVLink version is MAVLink 2.
Description
Component metadata message, which may be requested using MAV_CMD_REQUEST_MESSAGE.
This contains the MAVLink FTP URI and CRC for the component’s general metadata file. The file must be hosted on the component, and may be xz compressed. The file CRC can be used for file caching.
The general metadata file can be read to get the locations of other metadata files (COMP_METADATA_TYPE) and translations, which may be hosted either on the vehicle or the internet. For more information see: https://mavlink.io/en/services/component_information.html.
Note: Camera components should use CAMERA_INFORMATION instead, and autopilots may use both this message and AUTOPILOT_VERSION.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
ComponentMetadata (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
time_boot_ms: u32MAVLink field time_boot_ms.
Timestamp (time since system boot).
file_crc: u32MAVLink field file_crc.
CRC32 of the general metadata file.
uri: [u8; 100]MAVLink field uri.
MAVLink FTP URI for the general metadata file (COMP_METADATA_TYPE_GENERAL), which may be compressed with xz. The file contains general component metadata, and may contain URI links for additional metadata (see COMP_METADATA_TYPE). The information is static from boot, and may be generated at compile time. The string needs to be zero terminated.
Implementations
Sourceimpl ComponentMetadata
impl ComponentMetadata
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.