Struct DistanceSensor

pub struct DistanceSensor {
    pub time_boot_ms: u32,
    pub min_distance: u16,
    pub max_distance: u16,
    pub current_distance: u16,
    pub type_: MavDistanceSensor,
    pub id: u8,
    pub orientation: MavSensorOrientation,
    pub covariance: u8,
    pub horizontal_fov: f32,
    pub vertical_fov: f32,
    pub quaternion: [f32; 4],
    pub signal_quality: u8,
}
MAVLink DISTANCE_SENSOR message.

Minimum supported MAVLink version is MAVLink 1.

Description

Distance sensor information for an onboard rangefinder.

Encoding/Decoding

Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for DistanceSensor (encoding) and [IntoPayload] (decoding) traits. These traits are implemented by Message proc macro.

Fields

time_boot_ms: u32

MAVLink field time_boot_ms.

Timestamp (time since system boot).

min_distance: u16

MAVLink field min_distance.

Minimum distance the sensor can measure

max_distance: u16

MAVLink field max_distance.

Maximum distance the sensor can measure

current_distance: u16

MAVLink field current_distance.

Current distance reading

type_: MavDistanceSensor

MAVLink field type.

Type of distance sensor.

id: u8

MAVLink field id.

Onboard ID of the sensor

orientation: MavSensorOrientation

MAVLink field orientation.

Direction the sensor faces. downward-facing: ROTATION_PITCH_270, upward-facing: ROTATION_PITCH_90, backward-facing: ROTATION_PITCH_180, forward-facing: ROTATION_NONE, left-facing: ROTATION_YAW_90, right-facing: ROTATION_YAW_270

covariance: u8

MAVLink field covariance.

Measurement variance. Max standard deviation is 6cm. UINT8_MAX if unknown.

horizontal_fov: f32

MAVLink field horizontal_fov.

Horizontal Field of View (angle) where the distance measurement is valid and the field of view is known. Otherwise this is set to 0.

vertical_fov: f32

MAVLink field vertical_fov.

Vertical Field of View (angle) where the distance measurement is valid and the field of view is known. Otherwise this is set to 0.

quaternion: [f32; 4]

MAVLink field quaternion.

Quaternion of the sensor orientation in vehicle body frame (w, x, y, z order, zero-rotation is 1, 0, 0, 0). Zero-rotation is along the vehicle body x-axis. This field is required if the orientation is set to MAV_SENSOR_ROTATION_CUSTOM. Set it to 0 if invalid.“

signal_quality: u8

MAVLink field signal_quality.

Signal quality of the sensor. Specific to each sensor type, representing the relation of the signal strength with the target reflectivity, distance, size or aspect, but normalised as a percentage. 0 = unknown/unset signal quality, 1 = invalid signal, 100 = perfect signal.

Implementations

Source

impl DistanceSensor

pub const ID: MessageId = 132u32

MavLink message ID.

pub const fn spec() -> MessageInfo

Returns specification for this message.

pub const fn message_id() -> MessageId

Message ID.

pub const fn crc_extra() -> CrcExtra

Message CRC_EXTRA.

Minimum supported MAVLink version for this message.