pub struct GeneratorStatus {
pub status: MavGeneratorStatusFlag,
pub generator_speed: u16,
pub battery_current: f32,
pub load_current: f32,
pub power_generated: f32,
pub bus_voltage: f32,
pub rectifier_temperature: i16,
pub bat_current_setpoint: f32,
pub generator_temperature: i16,
pub runtime: u32,
pub time_until_maintenance: i32,
}Expand description
MAVLink GENERATOR_STATUS message.
The minimum supported MAVLink version is MAVLink 2.
Description
Telemetry of power generation system. Alternator or mechanical generator.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
GeneratorStatus (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
status: MavGeneratorStatusFlagMAVLink field status.
Status flags.
generator_speed: u16MAVLink field generator_speed.
Speed of electrical generator or alternator. UINT16_MAX: field not provided.
battery_current: f32MAVLink field battery_current.
Current into/out of battery. Positive for out. Negative for in. NaN: field not provided.
load_current: f32MAVLink field load_current.
Current going to the UAV. If battery current not available this is the DC current from the generator. Positive for out. Negative for in. NaN: field not provided
power_generated: f32MAVLink field power_generated.
The power being generated. NaN: field not provided
bus_voltage: f32MAVLink field bus_voltage.
Voltage of the bus seen at the generator, or battery bus if battery bus is controlled by generator and at a different voltage to main bus.
rectifier_temperature: i16MAVLink field rectifier_temperature.
The temperature of the rectifier or power converter. INT16_MAX: field not provided.
bat_current_setpoint: f32MAVLink field bat_current_setpoint.
The target battery current. Positive for out. Negative for in. NaN: field not provided
generator_temperature: i16MAVLink field generator_temperature.
The temperature of the mechanical motor, fuel cell core or generator. INT16_MAX: field not provided.
runtime: u32MAVLink field runtime.
Seconds this generator has run since it was rebooted. UINT32_MAX: field not provided.
time_until_maintenance: i32MAVLink field time_until_maintenance.
Seconds until this generator requires maintenance. A negative value indicates maintenance is past-due. INT32_MAX: field not provided.
Implementations
Sourceimpl GeneratorStatus
impl GeneratorStatus
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.