pub struct LinkNodeStatus {
pub timestamp: u64,
pub tx_buf: u8,
pub rx_buf: u8,
pub tx_rate: u32,
pub rx_rate: u32,
pub rx_parse_err: u16,
pub tx_overflows: u16,
pub rx_overflows: u16,
pub messages_sent: u32,
pub messages_received: u32,
pub messages_lost: u32,
}Expand description
MAVLink LINK_NODE_STATUS message.
The minimum supported MAVLink version is MAVLink 1.
Description
Status generated in each node in the communication chain and injected into MAVLink stream.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
LinkNodeStatus (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
timestamp: u64MAVLink field timestamp.
Timestamp (time since system boot).
tx_buf: u8MAVLink field tx_buf.
Remaining free transmit buffer space
rx_buf: u8MAVLink field rx_buf.
Remaining free receive buffer space
tx_rate: u32MAVLink field tx_rate.
Transmit rate
rx_rate: u32MAVLink field rx_rate.
Receive rate
rx_parse_err: u16MAVLink field rx_parse_err.
Number of bytes that could not be parsed correctly.
tx_overflows: u16MAVLink field tx_overflows.
Transmit buffer overflows. This number wraps around as it reaches UINT16_MAX
rx_overflows: u16MAVLink field rx_overflows.
Receive buffer overflows. This number wraps around as it reaches UINT16_MAX
messages_sent: u32MAVLink field messages_sent.
Messages sent
messages_received: u32MAVLink field messages_received.
Messages received (estimated from counting seq)
messages_lost: u32MAVLink field messages_lost.
Messages lost (estimated from counting seq)
Implementations
Sourceimpl LinkNodeStatus
impl LinkNodeStatus
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.