pub struct LocalPositionNedSystemGlobalOffset {
pub time_boot_ms: u32,
pub x: f32,
pub y: f32,
pub z: f32,
pub roll: f32,
pub pitch: f32,
pub yaw: f32,
}Expand description
MAVLink LOCAL_POSITION_NED_SYSTEM_GLOBAL_OFFSET message.
Minimum supported MAVLink version is MAVLink 1.
Description
The offset in X, Y, Z and yaw between the LOCAL_POSITION_NED messages of MAV X and the global coordinate frame in NED coordinates. Coordinate frame is right-handed, Z-axis down (aeronautical frame, NED / north-east-down convention)
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
LocalPositionNedSystemGlobalOffset (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
time_boot_ms: u32MAVLink field time_boot_ms.
Timestamp (time since system boot).
x: f32MAVLink field x.
X Position
y: f32MAVLink field y.
Y Position
z: f32MAVLink field z.
Z Position
roll: f32MAVLink field roll.
Roll
pitch: f32MAVLink field pitch.
Pitch
yaw: f32MAVLink field yaw.
Yaw
Implementations
Sourceimpl LocalPositionNedSystemGlobalOffset
impl LocalPositionNedSystemGlobalOffset
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.