pub struct OpticalFlowRad {
pub time_usec: u64,
pub sensor_id: u8,
pub integration_time_us: u32,
pub integrated_x: f32,
pub integrated_y: f32,
pub integrated_xgyro: f32,
pub integrated_ygyro: f32,
pub integrated_zgyro: f32,
pub temperature: i16,
pub quality: u8,
pub time_delta_distance_us: u32,
pub distance: f32,
}Expand description
MAVLink OPTICAL_FLOW_RAD message.
The minimum supported MAVLink version is MAVLink 1.
Description
Optical flow from an angular rate flow sensor (e.g. PX4FLOW or mouse sensor)
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
OpticalFlowRad (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
time_usec: u64MAVLink field time_usec.
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
sensor_id: u8MAVLink field sensor_id.
Sensor ID
integration_time_us: u32MAVLink field integration_time_us.
Integration time. Divide integrated_x and integrated_y by the integration time to obtain average flow. The integration time also indicates the.
integrated_x: f32MAVLink field integrated_x.
Flow around X axis (Sensor RH rotation about the X axis induces a positive flow. Sensor linear motion along the positive Y axis induces a negative flow.)
integrated_y: f32MAVLink field integrated_y.
Flow around Y axis (Sensor RH rotation about the Y axis induces a positive flow. Sensor linear motion along the positive X axis induces a positive flow.)
integrated_xgyro: f32MAVLink field integrated_xgyro.
RH rotation around X axis
integrated_ygyro: f32MAVLink field integrated_ygyro.
RH rotation around Y axis
integrated_zgyro: f32MAVLink field integrated_zgyro.
RH rotation around Z axis
temperature: i16MAVLink field temperature.
Temperature
quality: u8MAVLink field quality.
Optical flow quality / confidence. 0: no valid flow, 255: maximum quality
time_delta_distance_us: u32MAVLink field time_delta_distance_us.
Time since the distance was sampled.
distance: f32MAVLink field distance.
Distance to the center of the flow field. Positive value (including zero): distance known. Negative value: Unknown distance.
Implementations
Sourceimpl OpticalFlowRad
impl OpticalFlowRad
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.