Struct ParamExtValue

pub struct ParamExtValue {
    pub param_id: [u8; 16],
    pub param_value: [u8; 128],
    pub param_type: MavParamExtType,
    pub param_count: u16,
    pub param_index: u16,
}
MAVLink PARAM_EXT_VALUE message.

Minimum supported MAVLink version is MAVLink 2.

Description

Emit the value of a parameter. The inclusion of param_count and param_index in the message allows the recipient to keep track of received parameters and allows them to re-request missing parameters after a loss or timeout.

Encoding/Decoding

Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for ParamExtValue (encoding) and [IntoPayload] (decoding) traits. These traits are implemented by Message proc macro.

Fields

param_id: [u8; 16]

MAVLink field param_id.

Parameter id, terminated by NULL if the length is less than 16 human-readable chars and WITHOUT null termination (NULL) byte if the length is exactly 16 chars - applications have to provide 16+1 bytes storage if the ID is stored as string

param_value: [u8; 128]

MAVLink field param_value.

Parameter value

param_type: MavParamExtType

MAVLink field param_type.

Parameter type.

param_count: u16

MAVLink field param_count.

Total number of parameters

param_index: u16

MAVLink field param_index.

Index of this parameter

Implementations

Source

impl ParamExtValue

pub const ID: MessageId = 322u32

MavLink message ID.

pub const fn spec() -> MessageInfo

Returns specification for this message.

pub const fn message_id() -> MessageId

Message ID.

pub const fn crc_extra() -> CrcExtra

Message CRC_EXTRA.

Minimum supported MAVLink version for this message.