pub struct SystemTime {
pub time_unix_usec: u64,
pub time_boot_ms: u32,
}Expand description
MAVLink SYSTEM_TIME message.
Minimum supported MAVLink version is MAVLink 1.
Description
The system time is the time of the master clock, typically the computer clock of the main onboard computer.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
SystemTime (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
time_unix_usec: u64MAVLink field time_unix_usec.
Timestamp (UNIX epoch time).
time_boot_ms: u32MAVLink field time_boot_ms.
Timestamp (time since system boot).
Implementations
Sourceimpl SystemTime
impl SystemTime
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.