pub struct FigureEightExecutionStatus {
pub time_usec: u64,
pub major_radius: f32,
pub minor_radius: f32,
pub orientation: f32,
pub frame: MavFrame,
pub x: i32,
pub y: i32,
pub z: f32,
}Expand description
MAVLink FIGURE_EIGHT_EXECUTION_STATUS message.
Minimum supported MAVLink version is MAVLink 2.
Description
Vehicle status report that is sent out while figure eight execution is in progress (see MAV_CMD_DO_FIGURE_EIGHT). This may typically send at low rates: of the order of 2Hz.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
FigureEightExecutionStatus (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
time_usec: u64MAVLink field time_usec.
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
major_radius: f32MAVLink field major_radius.
Major axis radius of the figure eight. Positive: orbit the north circle clockwise. Negative: orbit the north circle counter-clockwise.
minor_radius: f32MAVLink field minor_radius.
Minor axis radius of the figure eight. Defines the radius of two circles that make up the figure.
orientation: f32MAVLink field orientation.
Orientation of the figure eight major axis with respect to true north in [-pi,pi).
frame: MavFrameMAVLink field frame.
The coordinate system of the fields: x, y, z.
x: i32MAVLink field x.
X coordinate of center point. Coordinate system depends on frame field.
y: i32MAVLink field y.
Y coordinate of center point. Coordinate system depends on frame field.
z: f32MAVLink field z.
Altitude of center point. Coordinate system depends on frame field.
Implementations
Sourceimpl FigureEightExecutionStatus
impl FigureEightExecutionStatus
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> MessageId
pub const fn message_id() -> MessageId
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.