pub type Statustext = Statustext;Expand description
Originally defined in common::messages::statustext.
Aliased Type
pub struct Statustext {
pub severity: MavSeverity,
pub text: [u8; 50],
pub id: u16,
pub chunk_seq: u8,
}Fields
severity: MavSeverityMAVLink field severity.
Severity of status. Relies on the definitions within RFC-5424.
text: [u8; 50]MAVLink field text.
Status text message, without null termination character
id: u16MAVLink field id.
Unique (opaque) identifier for this statustext message. May be used to reassemble a logical long-statustext message from a sequence of chunks. A value of zero indicates this is the only chunk in the sequence and the message can be emitted immediately.
chunk_seq: u8MAVLink field chunk_seq.
This chunk’s sequence number; indexing is from zero. Any null character in the text field is taken to mean this was the last chunk.