pub type Timesync = Timesync;Expand description
Originally defined in common::messages::timesync.
Aliased Type
pub struct Timesync {
pub tc1: i64,
pub ts1: i64,
pub target_system: u8,
pub target_component: u8,
}Fields
tc1: i64MAVLink field tc1.
Time sync timestamp 1. Syncing: 0. Responding: Timestamp of responding component.
ts1: i64MAVLink field ts1.
Time sync timestamp 2. Timestamp of syncing component (mirrored in response).
target_system: u8MAVLink field target_system.
Target system id. Request: 0 (broadcast) or id of specific system. Response must contain system id of the requesting component.
target_component: u8MAVLink field target_component.
Target component id. Request: 0 (broadcast) or id of specific component. Response must contain component id of the requesting component.