pub type GimbalManagerSetAttitude = GimbalManagerSetAttitude;Expand description
Originally defined in common::messages::gimbal_manager_set_attitude.
Aliased Type
pub struct GimbalManagerSetAttitude {
pub target_system: u8,
pub target_component: u8,
pub flags: GimbalManagerFlags,
pub gimbal_device_id: u8,
pub q: [f32; 4],
pub angular_velocity_x: f32,
pub angular_velocity_y: f32,
pub angular_velocity_z: f32,
}Fields
target_system: u8MAVLink field target_system.
System ID
target_component: u8MAVLink field target_component.
Component ID
flags: GimbalManagerFlagsMAVLink field flags.
High level gimbal manager flags to use.
gimbal_device_id: u8MAVLink field gimbal_device_id.
Component ID of gimbal device to address (or 1-6 for non-MAVLink gimbal), 0 for all gimbal device components. Send command multiple times for more than one gimbal (but not all gimbals).
q: [f32; 4]MAVLink field q.
Quaternion components, w, x, y, z (1 0 0 0 is the null-rotation, the frame is depends on whether the flag GIMBAL_MANAGER_FLAGS_YAW_LOCK is set)
angular_velocity_x: f32MAVLink field angular_velocity_x.
X component of angular velocity, positive is rolling to the right, NaN to be ignored.
angular_velocity_y: f32MAVLink field angular_velocity_y.
Y component of angular velocity, positive is pitching up, NaN to be ignored.
angular_velocity_z: f32MAVLink field angular_velocity_z.
Z component of angular velocity, positive is yawing to the right, NaN to be ignored.